extensions [array gis profiler Rnd]
breed [groups group]
groups-own [
  trait_list
  trait_list_copy
  port_count
  spain_count
  france_count
  valencia_count
  jura_count
  italy_count
  port_freq
  spain_freq
  france_freq
  valencia_freq
  jura_freq
  italy_freq
  cult
  home_patch
  done
  age
  last_move_dist
  old_patch
]
globals [
  land-patches
  land
  land-color
  mean-suitability
  port_color
  spain_color
  france_color
  valencia_color
  jura_color
  italy_color
  suitability-dataset
  core-dataset
  region-dataset

  birthrate_mo
  deathrate_mo
]
patches-own [
  suitability
  core
  occfreq
  region
  fallow
]

;;core/region numerical assignments
;; 1 = Portugal
;; 2 = Northern Spain
;; 3 = France and bit of Spain's Med coast
;; 4 = Valencia
;; 5 = Jura
;; 6 = Italy

to setup
  ca
  ;Import the three raster maps used to influence mobility and track agent movement
  set suitability-dataset gis:load-dataset (word "../data/26pc_hs.asc")
  gis:set-world-envelope (gis:envelope-of suitability-dataset)
  gis:apply-raster suitability-dataset suitability
  set core-dataset gis:load-dataset (word "../data/26pc_core.asc")
  gis:apply-raster core-dataset core
  set region-dataset gis:load-dataset (word "../data/26pc_region.asc")
  gis:apply-raster region-dataset region

  set land-patches patches with [suitability > 0]
  set port_color 125 ;; magenta
  set spain_color 65 ;; lime
  set france_color 115 ;; violet
  set valencia_color 85 ;; cyan
  set jura_color 95 ;; sky
  set italy_color 15 ;; red

  ;; The model's timestep is one month, so the annual birthrates are divided into monthly values for use in the population dynamics
  set birthrate_mo birthrate / 12
  ;; Deathrate setup options
  ifelse hs_death? = false [           ;deathrate is set to be equal to the birthrate which will keep the population roughly stable
    set deathrate_mo birthrate_mo
  ][ ;else hs_death? = true so use hs_benefit to sort out the effect of HS on deathrates by deriving a linear equation
    let death_hs_0.5 birthrate_mo
    let death_hs_1.0 death_hs_0.5 - (birthrate_mo * hs_benefit)
    set death_slope precision ((death_hs_1.0 - death_hs_0.5) / (1 - 0.5)) 7
    set death_yintercept precision (death_hs_1.0 + (-1 * death_slope * 1)) 7
  ]

  setup-patches
  setup-groups-randomly

  reset-ticks
end

to setup-patches
  ask patches [set pcolor white]
  set land patches with [suitability > 0]
  set land-color 5
  ask land [
    set fallow false
    set pcolor scale-color land-color suitability 0 1
  ]
end

to setup-groups-randomly
  ;Randomly distribute agents across the landscape and make sure they don't overlap on patches
  create-groups number
  [
    set shape "circle"
    set size 2
    move-to one-of patches with [suitability > 0 and not any? groups-here and region > 0]
    create-trait_list 0
    set color orange
    set-home
  ]
end

to setup-group-culture        ;assigns the agent a trait list and colour when they encounter a "core" cell in one of the six regions
  create-trait_list core
  set cult region
  if cult = 1 [set color port_color set cult "Portugal"]
  if cult = 2 [set color spain_color set cult "Spain"]
  if cult = 3 [set color france_color set cult "France"]
  if cult = 4 [set color valencia_color set cult "Valencia"]
  if cult = 5 [set color jura_color set cult "Jura"]
  if cult = 6 [set color italy_color set cult "Italy"]
end

to create-trait_list [genotype]            ;creates the "genome" of the agent as a paired list of values (1 to 6 depending on their region)
  set trait_list array:from-list n-values (trait_list_size) [0]
  foreach n-values trait_list_size [ [?1] -> ?1 ] [ [?1] ->
    let genepair list genotype genotype
    array:set trait_list ?1 genepair
  ]

  if genotype = 1 [
    set port_freq 1
    set port_count 2 * trait_list_size
    ]
  if genotype = 2 [
    set spain_freq 1
    set spain_count 2 * trait_list_size
    ]
  if genotype = 3 [
    set france_freq 1
    set france_count 2 * trait_list_size
    ]
  if genotype = 4 [
    set valencia_freq 1
    set valencia_count 2 * trait_list_size
    ]
  if genotype = 5 [
    set jura_freq 1
    set jura_count 2 * trait_list_size
    ]
  if genotype = 6 [
    set italy_freq 1
    set italy_count 2 * trait_list_size
    ]
end

to set-home       ;marks the center of their home_range to maintain home range fidelity
  set home_patch patch-here
end

to go
  if count groups = 0 or (max-ticks > 0 and ticks >= max-ticks)
    [ stop ]

  set mean-suitability mean [suitability] of groups

  ask groups [
    set age age + 1
    set done 0
    set old_patch patch-here

    ;; Agent movement section controlled by interface tab parameters
    move-to home_patch
    ifelse weight-move? [       ;if this is switch is on then movement is a random walk weighted by the HS value of each patch
      ifelse idw-weight = 0 [   ;if idw-weight is set to zero, distance to a cell is not considered
        carefully [move-to wrs_n200 fradius] [     ;this version of the movement algorithm improves computational time by considering a random 200 cells in the fradius
          let p wrs fradius                        ;if it can't find 200 cells (due to being on a peninsula for example), then it runs this backup instead
          if p != nobody [move-to p]
        ]
      ][; if idw-weight is greater than zero, then distance is also factored into which cell is chosen such that closer cells are preferred
        carefully [move-to wrsidw_n200 fradius] [   ;again this is used for computational efficiency with a backup in case too few cells are in the fradius
          let p wrsidw fradius
          if p != nobody [move-to p]
        ]
      ]
    ][ ;if the weight-move? switch is false, then agents either do a completely unweighted random walk (idw-weight = 0) or a distance weighted random walk
      ifelse idw-weight = 0 [
        right random 360
        jump random fradius
        if (suitability <= 0 or fallow = true or any? other groups-here) [
          move-to home_patch
        ]
      ][; if idw-weight is greater than zero, then distance is factored into which cell is chosen such that closer cells are preferred
        let p randidw (fradius + 1)
        if p != nobody [move-to p]
      ]
    ]

    ;record of occupation history is tracked by patches
    set occfreq occfreq + 1
    ;each agent records the length of their last move, this is optionally plotted in the interface tab to see the effect of idw-weight
    set last_move_dist distance home_patch
    ;if the agent doesn't have a genome yet and they have landed on a core cell, they get a genome full of that core cell's regional value
    if (item 0 array:item trait_list 0 = 0) and (core > 0) [setup-group-culture]

    ;; reproduction routine, vertical (genetic) change
    Reproduce

  ]

  ; Patches can't be occupied two timesteps in a row to allow for the habitat to recover, so
  ; the last timestep's occupied patches are marked as available (fallow false) then the currently occupied ones are marked fallow true
  ask patches with [fallow = true] [set fallow false]
  ask groups [
    set fallow true
  ]

  ;; death routine with options for whether HS is considered in the death routine or not
  ifelse hs_death? [
    hs_check_death
  ][
    Check_death
  ]

  tick
  if plotpop-on? [update-plot2]
end

to Check_Death           ;in initial experiments (see supplement) habitat suitability is not considered in the deathrates
  ask groups with [age > 0] [
      if random-float 1 < deathrate_mo [die]
    ]
end

to hs_check_death        ;calculates the deathrate based on the agent's current habitat suitability value (lower values = deathrate is higher)
  ask groups with [age > 0] [
    if random-float 1 < (death_slope * suitability) + death_yintercept [die]          ;y = death_slope*x + death_yintercept    calculated in setup
  ]
end

to Reproduce             ;if groups are set to reproduce they look for the closet other group to be a mate, and "hatch" a new group
  if random-float 1 < birthrate_mo [
    ;mate choice is different from Barton's model to be closest instead of a random agent in the fradius, indirectly this results in avoidance without their avoidance parameter
    let mate min-one-of other groups in-radius fradius [distance myself]
    hatch-groups 1 [
      set age 0
      if mate != nobody [
        ;if there is another viable group to mate with, run routine, otherwise the agent is just a clone of the single parent
        Indep_Assort mate
      ]
      ;the offspring agent moves to an empty and suitable cell, then marks it as the center of their home-range
      let p one-of patches in-radius fradius with [suitability > 0 and not any? groups-here and fallow = false]
      ifelse p != nobody [move-to p][die]
      ifelse count groups-here > 1 [die][set-home]
    ]
  ]
end

to Indep_Assort [mate]
  ;the newly hatched group builds it's genome by randomly picking from one parent or the other for each allele

  set port_count 0
  set spain_count 0
  set france_count 0
  set valencia_count 0
  set jura_count 0
  set italy_count 0

  foreach n-values trait_list_size [ [?1] -> ?1 ] [ [?1] ->
    let genepair array:item trait_list ?1
    let genepair-mate [array:item trait_list ?1] of mate

    ifelse random 2 = 0 [  ;; replace allele 0 with one of mate's alleles
      ifelse random 2 = 0 [
        set genepair replace-item 0 genepair item 0 genepair-mate ;; replace allele 0 with mate allele 0
      ][
        set genepair replace-item 0 genepair item 1 genepair-mate ;; replace allele 0 with mate allele 1
      ]
    ][  ;; replace allele 1 with one of mate's alleles
    ifelse random 2 = 0 [
      set genepair replace-item 1 genepair item 0 genepair-mate ;; replace allele 1 with mate allele 0
    ][
      set genepair replace-item 1 genepair item 1 genepair-mate ;; replace allele 1 with mate allele 1
    ]
    ]

    array:set trait_list ?1 genepair

    ;the regional traits are then summed
    if item 0 genepair = 1 [set port_count port_count + 1]
    if item 1 genepair = 1 [set port_count port_count + 1]
    if item 0 genepair = 2 [set spain_count spain_count + 1]
    if item 1 genepair = 2 [set spain_count spain_count + 1]
    if item 0 genepair = 3 [set france_count france_count + 1]
    if item 1 genepair = 3 [set france_count france_count + 1]
    if item 0 genepair = 4 [set valencia_count valencia_count + 1]
    if item 1 genepair = 4 [set valencia_count valencia_count + 1]
    if item 0 genepair = 5 [set jura_count jura_count + 1]
    if item 1 genepair = 5 [set jura_count jura_count + 1]
    if item 0 genepair = 6 [set italy_count italy_count + 1]
    if item 1 genepair = 6 [set italy_count italy_count + 1]
  ]

  ;and then regional trait frequencies are calculated
  set port_freq port_count / (2 * trait_list_size)
  set spain_freq spain_count / (2 * trait_list_size)
  set france_freq france_count / (2 * trait_list_size)
  set valencia_freq valencia_count / (2 * trait_list_size)
  set jura_freq jura_count / (2 * trait_list_size)
  set italy_freq italy_count / (2 * trait_list_size)

  let freqs (list port_freq spain_freq france_freq valencia_freq jura_freq italy_freq)
  let max_freq max freqs
  let max_cult (position max_freq freqs) + 1

  ; lastly the new agent's color is set by their most common regional trait
  if max_cult = 1 and max_freq > 0 [set color port_color]
  if max_cult = 2 [set color spain_color]
  if max_cult = 3 [set color france_color]
  if max_cult = 4 [set color valencia_color]
  if max_cult = 5 [set color jura_color]
  if max_cult = 6 [set color italy_color]

end

to update-plot2
  set-current-plot "Regional Population Sizes"
  set-current-plot-pen "Portugal"
  plot count groups with [region = 1]
  set-current-plot-pen "Spain"
  plot count groups with [region = 2]
  set-current-plot-pen "France"
  plot count groups with [region = 3]
  set-current-plot-pen "Valencia"
  plot count groups with [region = 4]
  set-current-plot-pen "Jura"
  plot count groups with [region = 5]
  set-current-plot-pen "Italy"
  plot count groups with [region = 6]
  set-current-plot-pen "Total"
  plot count groups
end

to-report patches-at-radius [rad]
    report (patch-set patches with [distance myself > rad - 1 AND distance myself <= rad])
end

;;;;;;;;;;;  WEIGHTED RANDOM SELECT PROCEDURES  ;;;;;;;;;;;;;;;;;;;;;;;;;
;; the various versions of the weighted random-walk depending on radii and interface parameter settings (see go procedure)
;; the basic idea is to have a single cell selected from a given set of cells based on the [reporter] at the end of each line that contains the probability weights
;; that may be just distance (randidw), just suitabilty (wrs), or a blending of the two (wrsidw)
;; see the documentation of the Rnd extension's "rnd:weighted-one-of" or the article supplement for more details
to-report wrs [radius]                ;weighted random-select of a suitable patch with suitability value as the weighting
  report rnd:weighted-one-of          other patches in-radius radius with [suitability >= 0 and fallow = false and not any? groups-here ] [suitability]
end

to-report wrs_n200 [radius]           ;for large radii this version of wrs is used for computational efficiency, only a random 200 cells within the radius are looked at
  report rnd:weighted-one-of n-of 200 other patches in-radius radius with [suitability >= 0 and fallow = false and not any? groups-here ] [suitability]
end

; for discussion of the idw-weight effect, see the supplement
to-report wrsidw [radius]             ;weighs distance against the suitability value combined_weight=suitability*dist^-p where p is best set at 2.0, based on Brantingham 2006's Levy random walks
  report rnd:weighted-one-of          other patches in-radius radius with [suitability >= 0 and fallow = false and not any? groups-here] [suitability * (( distance myself + 1) ^ (-1 * idw-weight))]
end

to-report wrsidw_n200 [radius]        ;version of wrsidw used for high radii values for computational efficiency
  report rnd:weighted-one-of n-of 200 other patches in-radius radius with [suitability >= 0 and fallow = false and not any? groups-here] [suitability * (( distance myself + 1) ^ (-1 * idw-weight ))]
end

to-report randidw [radius]            ;distance only weighting the random walk
  report rnd:weighted-one-of          other patches in-radius radius with [suitability >= 0 and fallow = false and not any? groups-here] [(( distance myself + 1) ^ (-1 * idw-weight))]
end

to-report cell-res
  let coords gis:envelope-of patch (max-pxcor / 2) (max-pycor / 2 )
  report (item 1 coords - item 0 coords) / 1000
end

;; Shifts the map display to the occupation frequency map exported at the end of runs
to display-occ
  ask groups [set hidden? true]
  let max_occ max [occfreq] of patches
  ask land [set pcolor scale-color red occfreq 0 max_occ]
end

; Alternate version of the occupation frequency map with a contrast stretch
to display-occ2   ;2.5 sd to mimic arcgis's contrast stretch
  ask groups [set hidden? true]
  let mean_occ mean [occfreq] of patches
  let max_occ max [occfreq] of patches
  let sd_occ standard-deviation [occfreq] of patches
  let min_occ mean_occ - (sd_occ * 2.5)
  let maxsd_occ mean_occ + (sd_occ * 2.5)
  if min_occ < 0 [set min_occ 1]
  ask land [set pcolor scale-color red occfreq min_occ maxsd_occ ]
end

to display-cores
  ask groups [set hidden? false]
  ask land with [core > 0] [
    if core = 1 [set pcolor port_color + 2]
    if core = 2 [set pcolor spain_color + 2]
    if core = 3 [set pcolor france_color + 2]
    if core = 4 [set pcolor valencia_color + 2]
    if core = 5 [set pcolor jura_color + 2]
    if core = 6 [set pcolor italy_color + 2]
  ]
end

; Copyright 2008 by Michael Barton.  All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Michael Barton.
; Contact Michael Barton for appropriate licenses for redistribution for
; profit.
;
; To refer to this model in academic publications, please use:
; Barton, C.M. (2008).  NetLogo Hybridization 1 Model.
@#$#@#$#@
GRAPHICS-WINDOW
145
195
778
687
-1
-1
1.0
1
10
1
1
1
0
0
0
1
0
624
0
482
1
1
1
ticks
30.0

BUTTON
80
10
135
43
run
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
5
10
60
43
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
5
50
135
83
number
number
1000
10000
7000.0
1000
1
NIL
HORIZONTAL

SLIDER
5
85
135
118
birthrate
birthrate
0
0.4
0.176
.01
1
%/yr
HORIZONTAL

SLIDER
5
120
135
153
fradius
fradius
0
50
20.0
10
1
NIL
HORIZONTAL

INPUTBOX
275
10
380
70
max-ticks
3001.0
1
0
Number

BUTTON
150
10
205
43
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
280
80
380
135
You must press <return> after changing max-generation
10
0.0
1

TEXTBOX
160
205
310
231
1 cell = 5 x 5 km
11
139.0
1

MONITOR
270
145
377
190
Total pop
count groups\n;sum [Ncount] of variants with [v-type = \"MM\" or v-type = \"M-type\"]  / (sum [Mcount + Ncount + (2 * Hloci)] of variants with [v-type = \"MM\" or v-type = \"M-type\"])
0
1
11

SLIDER
5
315
135
348
trait_list_size
trait_list_size
0
1000
100.0
1
1
NIL
HORIZONTAL

BUTTON
32
395
142
428
disp core areas
ask groups [set hidden? false]\nifelse ([pcolor] of one-of patches with [core = 1] > 10)\n[\nask land [set pcolor scale-color land-color suitability 0 1]\n][\nask patches with [core > 0] [\n  if core = 1 [set pcolor port_color + 2]\n  if core = 2 [set pcolor spain_color + 2]\n  if core = 3 [set pcolor france_color + 2]\n  if core = 4 [set pcolor valencia_color + 2]\n  if core = 5 [set pcolor jura_color + 2]\n  if core = 6 [set pcolor italy_color + 2]\n  ]\n  ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
135
120
190
153
rad
ask one-of groups [ ask patches-at-radius fradius [set pcolor blue]]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
910
315
972
348
profile
;setup                  ;; set up the model\nprofiler:start         ;; start profiling\nrepeat 50 [ go ]       ;; run something you want to measure\nprofiler:stop          ;; stop profiling\nprint profiler:report  ;; view the results\nprofiler:reset         ;; clear the data
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
5
235
135
268
weight-move?
weight-move?
0
1
-1000

BUTTON
975
315
1087
348
profiler-module
;setup                  ;; set up the model\nprofiler:start         ;; start profiling\nrepeat 1000 [\n ask one-of groups [\n   let a wrsidw fradius\n   let b wrs fradius\n ] \n ]       ;; run something you want to measure\nprofiler:stop          ;; stop profiling\nprint profiler:report  ;; view the results\nprofiler:reset         ;; clear the data
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
15
270
140
303
idw-weight
idw-weight
0
4
2.0
.5
1
NIL
HORIZONTAL

SWITCH
5
160
115
193
hs_death?
hs_death?
1
1
-1000

BUTTON
32
430
142
463
disp regions
ask groups [set hidden? false]\nifelse ([pcolor] of one-of patches with [region = 1] > 10)\n[\nask land [set pcolor scale-color land-color suitability 0 1]\n][\nask land with [region > 0] [\n  if region = 1 [set pcolor port_color + 2]\n  if region = 2 [set pcolor spain_color + 2]\n  if region = 3 [set pcolor france_color + 2]\n  if region = 4 [set pcolor valencia_color + 2]\n  if region = 5 [set pcolor jura_color + 2]\n  if region = 6 [set pcolor italy_color + 2]\n  ]\n  ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
390
10
785
195
Regional Population Sizes
Time (Months)
Population size
0.0
1200.0
0.0
10.0
true
true
"" ""
PENS
"Portugal" 1.0 0 -5825686 true "" ""
"Spain" 1.0 0 -13840069 true "" ""
"France" 1.0 0 -8630108 true "" ""
"Valencia" 1.0 0 -11221820 true "" ""
"Jura" 1.0 0 -13791810 true "" ""
"Italy" 1.0 0 -2674135 true "" ""
"Total" 1.0 0 -7500403 true "" ""

SWITCH
820
70
910
103
plots?
plots?
1
1
-1000

PLOT
1110
160
1310
310
Distance of last move (cells)
NIL
NIL
0.0
40.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "if plots? [histogram [last_move_dist] of groups]"

PLOT
1110
10
1310
160
Agent ages (months)
NIL
NIL
0.0
500.0
0.0
10.0
true
false
"" ""
PENS
"default" 10.0 1 -16777216 true "" "if plots? [histogram [age] of groups with [age < ticks]]"

PLOT
910
10
1110
160
HS of groups
NIL
NIL
0.0
1.0
0.0
10.0
true
false
"" ""
PENS
"default" 0.05 1 -16777216 true "" "if plots? [histogram [suitability] of groups]"

INPUTBOX
15
565
125
625
death_slope
-0.0293333
1
0
Number

INPUTBOX
15
625
125
685
death_yintercept
0.0293333
1
0
Number

SWITCH
785
10
890
43
plotpop-on?
plotpop-on?
0
1
-1000

SLIDER
15
195
125
228
hs_benefit
hs_benefit
0
1
0.0
0.25
1
NIL
HORIZONTAL

BUTTON
32
465
142
498
disp occ freq
display-occ2
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
910
160
1110
310
Occ freq of patches
NIL
NIL
1.0
750.0
0.0
1000.0
false
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "if plots? [histogram [occfreq] of patches]"

TEXTBOX
21
532
118
561
Calculated in setup\nusing hs_benefit
11
0.0
1

TEXTBOX
830
110
915
128
Diagnostic plots
11
0.0
1

@#$#@#$#@
## MODEL OVERVIEW (modified from Barton's original)

This model simulates genetic interaction and hybridization between six regional populations using a 10-locus multi-allele system. These interactions occur on a heterogeneous map of habitat suitability set in western Eurasia during the Last Glacial Maximum. The survival and degree of mixing of the various regional populations can be measured as population sizes and trait frequencies in the final population (see behaviorspace exports). This simulation uses the NetLogo array and Rnd extensions.

## MODEL FUNCTION

## INIITAL STATE:

The model is initiated with a randomly scattered population of agents and a null genome of zeros. The agents aquire a genome, composed of their area's regional code (1-6) when they move to a core area cell.

AGENTS: Each individual has:
  * a genome of 100 allele pairs and each allele can have a value from 1 to 6,
  * a pheno/genotype & colour based on the highest gene frequencies of their loci, and
  * a 'home base' specified by xy coordinates <home-x> and <home-y>

MOVEMENT: Each cycle, individual agents begin at their home base and randomly jump to a patch within their foraging radius <fradius> set by the user. Cell resolution is 5km so 10 cell radius = 50 km. Movement occurs as a weighted random-walk (Rnd extension) with weightings corresponding to inverse distance and/or habitat suitability. If weight-move? is off an unweighted random-walk occurs, if weight-move? is on, idw-weight of 0 will ignore distance but use suitability, if idw-weight > 0 both are used in combination. An idw-weight of 2 will prefer closer cells (see "Distance of last move" plot).

REPRODUCTION: The user can set the birthrate on the interface tab (0 to 1). If an agent is to reproduce on a given timestep, they choose the nearest other agent to reproduce with. When 2 individuals mate, a genetic 'independent assortment' routine creates an offspring genome from that of its parents. The new individual will jump to a new empty patch that is randomly selected from within the foraging radius <fradius>.

DEATH: If hs_death? is off, the deathrate is set to be equal to the birthrate. If hs_death? is on, habitat suitability affects deathrate according to a linear equation relating HS to deathrate. The strength of the effect of HS on deathrate may be adjusted with hs_benefit (0 to 1) with higher values having a stronger effect (more likely to die if on low HS values).

## STARTING THE SIMULATION

Sliders allow the user to set the initial number of individuals and the size of the genome in addition to the above parameters.

The SETUP button imports the habitat suitability landscape (26pc_hs.asc), the core area and region designations and initializes the model. The RUN button starts and stops the model. Pressing STEP rather than RUN will manually step through each cycle.

The simulation can be set to stop after a specific number of cycles by entering that number in max-generations box. You must press RETURN after entering a number. Entering 0 will cause the simulation to run continuously until the RUN button is pressed.

The plots and monitors show the total number of individuals in each region, among other diagnostic plots. The color of each agent indicates their dominant genetic makeup.

## THINGS TO TRY

Alter the switches relating to mobility and the effect of HS on the deathrate. Note that increasing the fradius, turning on hs_death?, and larger population sizes dramatically slow down the computation speed of the model

## RELATED MODELS

Hominin ecodyamics v. 1.0 and v. 2.0, published in:

Barton, C. Michael, Julien Riel-Salvatore, John M. Anderies, & Gabriel Popescu (2011). Modeling human ecodynamics and biocultural interactions in the Late Pleistocene of western Eurasia. Human Ecology. DOI: 10.1007/s10745-011-9433-8

Barton, C. Michael, and Julien Riel-Salvatore. 2012. ‘Agents of Change: Modeling Biocultural Evolution in Upper Pleistocene Western Eurasia’. Advances in Complex Systems 15 (01n02): 1150003. DOI: 10.1142/S0219525911003359


## CREDITS AND REFERENCES

C. Michael Barton, Arizona State University. Copyright 2011

C. Michael Barton & Julien Riel-Salvatore (2011). Agents of change: modeling biocultural evolution in Late Pleistocene western Eurasia. Advances in Complex Systems. DOI: 10.1142/S0219525911003359.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

box 2
false
0
Polygon -7500403 true true 150 285 270 225 270 90 150 150
Polygon -13791810 true false 150 150 30 90 150 30 270 90
Polygon -13345367 true false 30 90 30 225 150 285 150 150

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

train switcher engine
false
0
Polygon -7500403 true true 45 210 45 180 45 150 53 130 151 123 248 131 255 150 255 195 255 210 60 210
Circle -16777216 true false 225 195 30
Circle -16777216 true false 195 195 30
Circle -16777216 true false 75 195 30
Circle -16777216 true false 45 195 30
Line -7500403 true 150 135 150 165
Rectangle -7500403 true true 120 90 180 195
Rectangle -16777216 true false 132 98 170 120
Line -7500403 true 150 90 150 150
Rectangle -16777216 false false 120 90 180 180
Rectangle -7500403 true true 30 180 270 195
Rectangle -16777216 false false 30 180 270 195
Line -16777216 false 270 150 270 180
Rectangle -1 true false 245 131 252 138
Rectangle -1 true false 48 131 55 138
Polygon -16777216 true false 255 179 227 169 227 158 255 168
Polygon -16777216 true false 255 162 227 152 227 141 255 151
Polygon -16777216 true false 45 162 73 152 73 141 45 151
Polygon -16777216 true false 45 179 73 169 73 158 45 168
Rectangle -16777216 true false 112 195 187 210
Rectangle -16777216 true false 264 180 279 195
Rectangle -16777216 true false 21 180 36 195
Line -16777216 false 30 150 30 180
Line -16777216 false 120 98 180 98

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="ex1" repetitions="10" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>reset-timer
setup</setup>
    <go>go</go>
    <final>display-cores
ask groups [set size 4]
export-view (word "stills/ex1" "_wm" weight-move? "_rad" fradius "_" behaviorspace-run-number ".png")
display-occ2
export-view (word "stills/ex1" "_wm" weight-move? "_rad" fradius "_" behaviorspace-run-number "o.png")
export-plot "Regional population sizes" (word "stills/ex1" "_wm" weight-move? "_rad" fradius "_" behaviorspace-run-number ".csv")</final>
    <timeLimit steps="3000"/>
    <metric>count groups</metric>
    <metric>mean [port_freq] of groups with [region = 1]</metric>
    <metric>mean [spain_freq] of groups with [region = 1]</metric>
    <metric>mean [france_freq] of groups with [region = 1]</metric>
    <metric>mean [valencia_freq] of groups with [region = 1]</metric>
    <metric>mean [jura_freq] of groups with [region = 1]</metric>
    <metric>mean [italy_freq] of groups with [region = 1]</metric>
    <metric>mean [port_freq] of groups with [region = 2]</metric>
    <metric>mean [spain_freq] of groups with [region = 2]</metric>
    <metric>mean [france_freq] of groups with [region = 2]</metric>
    <metric>mean [valencia_freq] of groups with [region = 2]</metric>
    <metric>mean [jura_freq] of groups with [region = 2]</metric>
    <metric>mean [italy_freq] of groups with [region = 2]</metric>
    <metric>mean [port_freq] of groups with [region = 3]</metric>
    <metric>mean [spain_freq] of groups with [region = 3]</metric>
    <metric>mean [france_freq] of groups with [region = 3]</metric>
    <metric>mean [valencia_freq] of groups with [region = 3]</metric>
    <metric>mean [jura_freq] of groups with [region = 3]</metric>
    <metric>mean [italy_freq] of groups with [region = 3]</metric>
    <metric>mean [port_freq] of groups with [region = 4]</metric>
    <metric>mean [spain_freq] of groups with [region = 4]</metric>
    <metric>mean [france_freq] of groups with [region = 4]</metric>
    <metric>mean [valencia_freq] of groups with [region = 4]</metric>
    <metric>mean [jura_freq] of groups with [region = 4]</metric>
    <metric>mean [italy_freq] of groups with [region = 4]</metric>
    <metric>mean [port_freq] of groups with [region = 5]</metric>
    <metric>mean [spain_freq] of groups with [region = 5]</metric>
    <metric>mean [france_freq] of groups with [region = 5]</metric>
    <metric>mean [valencia_freq] of groups with [region = 5]</metric>
    <metric>mean [jura_freq] of groups with [region = 5]</metric>
    <metric>mean [italy_freq] of groups with [region = 5]</metric>
    <metric>mean [port_freq] of groups with [region = 6]</metric>
    <metric>mean [spain_freq] of groups with [region = 6]</metric>
    <metric>mean [france_freq] of groups with [region = 6]</metric>
    <metric>mean [valencia_freq] of groups with [region = 6]</metric>
    <metric>mean [jura_freq] of groups with [region = 6]</metric>
    <metric>mean [italy_freq] of groups with [region = 6]</metric>
    <metric>count groups with [region = 1]</metric>
    <metric>count groups with [region = 2]</metric>
    <metric>count groups with [region = 3]</metric>
    <metric>count groups with [region = 4]</metric>
    <metric>count groups with [region = 5]</metric>
    <metric>count groups with [region = 6]</metric>
    <metric>mean [suitability] of groups</metric>
    <metric>mean [suitability] of groups with [region = 1]</metric>
    <metric>mean [suitability] of groups with [region = 2]</metric>
    <metric>mean [suitability] of groups with [region = 3]</metric>
    <metric>mean [suitability] of groups with [region = 4]</metric>
    <metric>mean [suitability] of groups with [region = 5]</metric>
    <metric>mean [suitability] of groups with [region = 6]</metric>
    <metric>death_slope</metric>
    <metric>death_yintercept</metric>
    <metric>timer</metric>
    <enumeratedValueSet variable="number">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birthrate">
      <value value="0.176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weight-move?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fradius">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ticks">
      <value value="3001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trait_list_size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hs_death?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hs_benefit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idw-weight">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plotpop-on?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ex2" repetitions="10" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>reset-timer
setup</setup>
    <go>go</go>
    <final>display-cores
ask groups [set size 4]
export-view (word "stills/ex2" "_wm" weight-move? "_rad" fradius "_" behaviorspace-run-number ".png")
display-occ2
export-view (word "stills/ex2" "_wm" weight-move? "_rad" fradius "_" behaviorspace-run-number "o.png")
export-plot "Regional population sizes" (word "stills/ex2" "_wm" weight-move? "_rad" fradius "_" behaviorspace-run-number ".csv")</final>
    <timeLimit steps="3000"/>
    <metric>count groups</metric>
    <metric>mean [port_freq] of groups with [region = 1]</metric>
    <metric>mean [spain_freq] of groups with [region = 1]</metric>
    <metric>mean [france_freq] of groups with [region = 1]</metric>
    <metric>mean [valencia_freq] of groups with [region = 1]</metric>
    <metric>mean [jura_freq] of groups with [region = 1]</metric>
    <metric>mean [italy_freq] of groups with [region = 1]</metric>
    <metric>mean [port_freq] of groups with [region = 2]</metric>
    <metric>mean [spain_freq] of groups with [region = 2]</metric>
    <metric>mean [france_freq] of groups with [region = 2]</metric>
    <metric>mean [valencia_freq] of groups with [region = 2]</metric>
    <metric>mean [jura_freq] of groups with [region = 2]</metric>
    <metric>mean [italy_freq] of groups with [region = 2]</metric>
    <metric>mean [port_freq] of groups with [region = 3]</metric>
    <metric>mean [spain_freq] of groups with [region = 3]</metric>
    <metric>mean [france_freq] of groups with [region = 3]</metric>
    <metric>mean [valencia_freq] of groups with [region = 3]</metric>
    <metric>mean [jura_freq] of groups with [region = 3]</metric>
    <metric>mean [italy_freq] of groups with [region = 3]</metric>
    <metric>mean [port_freq] of groups with [region = 4]</metric>
    <metric>mean [spain_freq] of groups with [region = 4]</metric>
    <metric>mean [france_freq] of groups with [region = 4]</metric>
    <metric>mean [valencia_freq] of groups with [region = 4]</metric>
    <metric>mean [jura_freq] of groups with [region = 4]</metric>
    <metric>mean [italy_freq] of groups with [region = 4]</metric>
    <metric>mean [port_freq] of groups with [region = 5]</metric>
    <metric>mean [spain_freq] of groups with [region = 5]</metric>
    <metric>mean [france_freq] of groups with [region = 5]</metric>
    <metric>mean [valencia_freq] of groups with [region = 5]</metric>
    <metric>mean [jura_freq] of groups with [region = 5]</metric>
    <metric>mean [italy_freq] of groups with [region = 5]</metric>
    <metric>mean [port_freq] of groups with [region = 6]</metric>
    <metric>mean [spain_freq] of groups with [region = 6]</metric>
    <metric>mean [france_freq] of groups with [region = 6]</metric>
    <metric>mean [valencia_freq] of groups with [region = 6]</metric>
    <metric>mean [jura_freq] of groups with [region = 6]</metric>
    <metric>mean [italy_freq] of groups with [region = 6]</metric>
    <metric>count groups with [region = 1]</metric>
    <metric>count groups with [region = 2]</metric>
    <metric>count groups with [region = 3]</metric>
    <metric>count groups with [region = 4]</metric>
    <metric>count groups with [region = 5]</metric>
    <metric>count groups with [region = 6]</metric>
    <metric>mean [suitability] of groups</metric>
    <metric>mean [suitability] of groups with [region = 1]</metric>
    <metric>mean [suitability] of groups with [region = 2]</metric>
    <metric>mean [suitability] of groups with [region = 3]</metric>
    <metric>mean [suitability] of groups with [region = 4]</metric>
    <metric>mean [suitability] of groups with [region = 5]</metric>
    <metric>mean [suitability] of groups with [region = 6]</metric>
    <metric>death_slope</metric>
    <metric>death_yintercept</metric>
    <metric>timer</metric>
    <enumeratedValueSet variable="number">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birthrate">
      <value value="0.176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weight-move?">
      <value value="true"/>
    </enumeratedValueSet>
    <steppedValueSet variable="fradius" first="10" step="10" last="40"/>
    <enumeratedValueSet variable="max-ticks">
      <value value="3001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trait_list_size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hs_death?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hs_benefit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idw-weight">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plotpop-on?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ex3_r10" repetitions="10" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>reset-timer
setup</setup>
    <go>go</go>
    <final>display-cores
ask groups [set size 4]
export-view (word "stills/ex3" "_wm" weight-move? "_rad" fradius "_hsben" hs_benefit "_" behaviorspace-run-number ".png")
display-occ2
export-view (word "stills/ex3" "_wm" weight-move? "_rad" fradius "_hsben" hs_benefit "_" behaviorspace-run-number "o.png")
export-plot "Regional population sizes" (word "stills/ex3" "_wm" weight-move? "_rad" fradius "_hsben" hs_benefit "_" behaviorspace-run-number ".csv")</final>
    <timeLimit steps="3000"/>
    <metric>count groups</metric>
    <metric>mean [port_freq] of groups with [region = 1]</metric>
    <metric>mean [spain_freq] of groups with [region = 1]</metric>
    <metric>mean [france_freq] of groups with [region = 1]</metric>
    <metric>mean [valencia_freq] of groups with [region = 1]</metric>
    <metric>mean [jura_freq] of groups with [region = 1]</metric>
    <metric>mean [italy_freq] of groups with [region = 1]</metric>
    <metric>mean [port_freq] of groups with [region = 2]</metric>
    <metric>mean [spain_freq] of groups with [region = 2]</metric>
    <metric>mean [france_freq] of groups with [region = 2]</metric>
    <metric>mean [valencia_freq] of groups with [region = 2]</metric>
    <metric>mean [jura_freq] of groups with [region = 2]</metric>
    <metric>mean [italy_freq] of groups with [region = 2]</metric>
    <metric>mean [port_freq] of groups with [region = 3]</metric>
    <metric>mean [spain_freq] of groups with [region = 3]</metric>
    <metric>mean [france_freq] of groups with [region = 3]</metric>
    <metric>mean [valencia_freq] of groups with [region = 3]</metric>
    <metric>mean [jura_freq] of groups with [region = 3]</metric>
    <metric>mean [italy_freq] of groups with [region = 3]</metric>
    <metric>mean [port_freq] of groups with [region = 4]</metric>
    <metric>mean [spain_freq] of groups with [region = 4]</metric>
    <metric>mean [france_freq] of groups with [region = 4]</metric>
    <metric>mean [valencia_freq] of groups with [region = 4]</metric>
    <metric>mean [jura_freq] of groups with [region = 4]</metric>
    <metric>mean [italy_freq] of groups with [region = 4]</metric>
    <metric>mean [port_freq] of groups with [region = 5]</metric>
    <metric>mean [spain_freq] of groups with [region = 5]</metric>
    <metric>mean [france_freq] of groups with [region = 5]</metric>
    <metric>mean [valencia_freq] of groups with [region = 5]</metric>
    <metric>mean [jura_freq] of groups with [region = 5]</metric>
    <metric>mean [italy_freq] of groups with [region = 5]</metric>
    <metric>mean [port_freq] of groups with [region = 6]</metric>
    <metric>mean [spain_freq] of groups with [region = 6]</metric>
    <metric>mean [france_freq] of groups with [region = 6]</metric>
    <metric>mean [valencia_freq] of groups with [region = 6]</metric>
    <metric>mean [jura_freq] of groups with [region = 6]</metric>
    <metric>mean [italy_freq] of groups with [region = 6]</metric>
    <metric>count groups with [region = 1]</metric>
    <metric>count groups with [region = 2]</metric>
    <metric>count groups with [region = 3]</metric>
    <metric>count groups with [region = 4]</metric>
    <metric>count groups with [region = 5]</metric>
    <metric>count groups with [region = 6]</metric>
    <metric>mean [suitability] of groups</metric>
    <metric>mean [suitability] of groups with [region = 1]</metric>
    <metric>mean [suitability] of groups with [region = 2]</metric>
    <metric>mean [suitability] of groups with [region = 3]</metric>
    <metric>mean [suitability] of groups with [region = 4]</metric>
    <metric>mean [suitability] of groups with [region = 5]</metric>
    <metric>mean [suitability] of groups with [region = 6]</metric>
    <metric>death_slope</metric>
    <metric>death_yintercept</metric>
    <metric>timer</metric>
    <enumeratedValueSet variable="number">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birthrate">
      <value value="0.176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weight-move?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fradius">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ticks">
      <value value="3001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trait_list_size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hs_death?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hs_benefit">
      <value value="0"/>
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idw-weight">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plotpop-on?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ex3_r20" repetitions="10" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>reset-timer
setup</setup>
    <go>go</go>
    <final>display-cores
ask groups [set size 4]
export-view (word "stills/ex3" "_wm" weight-move? "_rad" fradius "_hsben" hs_benefit "_" behaviorspace-run-number ".png")
display-occ2
export-view (word "stills/ex3" "_wm" weight-move? "_rad" fradius "_hsben" hs_benefit "_" behaviorspace-run-number "o.png")
export-plot "Regional population sizes" (word "stills/ex3" "_wm" weight-move? "_rad" fradius "_hsben" hs_benefit "_" behaviorspace-run-number ".csv")</final>
    <timeLimit steps="3000"/>
    <metric>count groups</metric>
    <metric>mean [port_freq] of groups with [region = 1]</metric>
    <metric>mean [spain_freq] of groups with [region = 1]</metric>
    <metric>mean [france_freq] of groups with [region = 1]</metric>
    <metric>mean [valencia_freq] of groups with [region = 1]</metric>
    <metric>mean [jura_freq] of groups with [region = 1]</metric>
    <metric>mean [italy_freq] of groups with [region = 1]</metric>
    <metric>mean [port_freq] of groups with [region = 2]</metric>
    <metric>mean [spain_freq] of groups with [region = 2]</metric>
    <metric>mean [france_freq] of groups with [region = 2]</metric>
    <metric>mean [valencia_freq] of groups with [region = 2]</metric>
    <metric>mean [jura_freq] of groups with [region = 2]</metric>
    <metric>mean [italy_freq] of groups with [region = 2]</metric>
    <metric>mean [port_freq] of groups with [region = 3]</metric>
    <metric>mean [spain_freq] of groups with [region = 3]</metric>
    <metric>mean [france_freq] of groups with [region = 3]</metric>
    <metric>mean [valencia_freq] of groups with [region = 3]</metric>
    <metric>mean [jura_freq] of groups with [region = 3]</metric>
    <metric>mean [italy_freq] of groups with [region = 3]</metric>
    <metric>mean [port_freq] of groups with [region = 4]</metric>
    <metric>mean [spain_freq] of groups with [region = 4]</metric>
    <metric>mean [france_freq] of groups with [region = 4]</metric>
    <metric>mean [valencia_freq] of groups with [region = 4]</metric>
    <metric>mean [jura_freq] of groups with [region = 4]</metric>
    <metric>mean [italy_freq] of groups with [region = 4]</metric>
    <metric>mean [port_freq] of groups with [region = 5]</metric>
    <metric>mean [spain_freq] of groups with [region = 5]</metric>
    <metric>mean [france_freq] of groups with [region = 5]</metric>
    <metric>mean [valencia_freq] of groups with [region = 5]</metric>
    <metric>mean [jura_freq] of groups with [region = 5]</metric>
    <metric>mean [italy_freq] of groups with [region = 5]</metric>
    <metric>mean [port_freq] of groups with [region = 6]</metric>
    <metric>mean [spain_freq] of groups with [region = 6]</metric>
    <metric>mean [france_freq] of groups with [region = 6]</metric>
    <metric>mean [valencia_freq] of groups with [region = 6]</metric>
    <metric>mean [jura_freq] of groups with [region = 6]</metric>
    <metric>mean [italy_freq] of groups with [region = 6]</metric>
    <metric>count groups with [region = 1]</metric>
    <metric>count groups with [region = 2]</metric>
    <metric>count groups with [region = 3]</metric>
    <metric>count groups with [region = 4]</metric>
    <metric>count groups with [region = 5]</metric>
    <metric>count groups with [region = 6]</metric>
    <metric>mean [suitability] of groups</metric>
    <metric>mean [suitability] of groups with [region = 1]</metric>
    <metric>mean [suitability] of groups with [region = 2]</metric>
    <metric>mean [suitability] of groups with [region = 3]</metric>
    <metric>mean [suitability] of groups with [region = 4]</metric>
    <metric>mean [suitability] of groups with [region = 5]</metric>
    <metric>mean [suitability] of groups with [region = 6]</metric>
    <metric>death_slope</metric>
    <metric>death_yintercept</metric>
    <metric>timer</metric>
    <enumeratedValueSet variable="number">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birthrate">
      <value value="0.176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weight-move?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fradius">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ticks">
      <value value="3001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trait_list_size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hs_death?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hs_benefit">
      <value value="0"/>
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idw-weight">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plotpop-on?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ex3_r40" repetitions="1" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>reset-timer
setup</setup>
    <go>go</go>
    <final>display-cores
ask groups [set size 4]
let randnum random 100
export-view (word "stills/ex3" "_wm" weight-move? "_rad" fradius "_hsben" hs_benefit "_" behaviorspace-run-number randnum ".png")
display-occ2
export-view (word "stills/ex3" "_wm" weight-move? "_rad" fradius "_hsben" hs_benefit "_" behaviorspace-run-number randnum "o.png")
export-plot "Regional population sizes" (word "stills/ex3" "_wm" weight-move? "_rad" fradius "_hsben" hs_benefit "_" behaviorspace-run-number randnum ".csv")</final>
    <timeLimit steps="3000"/>
    <metric>count groups</metric>
    <metric>mean [port_freq] of groups with [region = 1]</metric>
    <metric>mean [spain_freq] of groups with [region = 1]</metric>
    <metric>mean [france_freq] of groups with [region = 1]</metric>
    <metric>mean [valencia_freq] of groups with [region = 1]</metric>
    <metric>mean [jura_freq] of groups with [region = 1]</metric>
    <metric>mean [italy_freq] of groups with [region = 1]</metric>
    <metric>mean [port_freq] of groups with [region = 2]</metric>
    <metric>mean [spain_freq] of groups with [region = 2]</metric>
    <metric>mean [france_freq] of groups with [region = 2]</metric>
    <metric>mean [valencia_freq] of groups with [region = 2]</metric>
    <metric>mean [jura_freq] of groups with [region = 2]</metric>
    <metric>mean [italy_freq] of groups with [region = 2]</metric>
    <metric>mean [port_freq] of groups with [region = 3]</metric>
    <metric>mean [spain_freq] of groups with [region = 3]</metric>
    <metric>mean [france_freq] of groups with [region = 3]</metric>
    <metric>mean [valencia_freq] of groups with [region = 3]</metric>
    <metric>mean [jura_freq] of groups with [region = 3]</metric>
    <metric>mean [italy_freq] of groups with [region = 3]</metric>
    <metric>mean [port_freq] of groups with [region = 4]</metric>
    <metric>mean [spain_freq] of groups with [region = 4]</metric>
    <metric>mean [france_freq] of groups with [region = 4]</metric>
    <metric>mean [valencia_freq] of groups with [region = 4]</metric>
    <metric>mean [jura_freq] of groups with [region = 4]</metric>
    <metric>mean [italy_freq] of groups with [region = 4]</metric>
    <metric>mean [port_freq] of groups with [region = 5]</metric>
    <metric>mean [spain_freq] of groups with [region = 5]</metric>
    <metric>mean [france_freq] of groups with [region = 5]</metric>
    <metric>mean [valencia_freq] of groups with [region = 5]</metric>
    <metric>mean [jura_freq] of groups with [region = 5]</metric>
    <metric>mean [italy_freq] of groups with [region = 5]</metric>
    <metric>mean [port_freq] of groups with [region = 6]</metric>
    <metric>mean [spain_freq] of groups with [region = 6]</metric>
    <metric>mean [france_freq] of groups with [region = 6]</metric>
    <metric>mean [valencia_freq] of groups with [region = 6]</metric>
    <metric>mean [jura_freq] of groups with [region = 6]</metric>
    <metric>mean [italy_freq] of groups with [region = 6]</metric>
    <metric>count groups with [region = 1]</metric>
    <metric>count groups with [region = 2]</metric>
    <metric>count groups with [region = 3]</metric>
    <metric>count groups with [region = 4]</metric>
    <metric>count groups with [region = 5]</metric>
    <metric>count groups with [region = 6]</metric>
    <metric>mean [suitability] of groups</metric>
    <metric>mean [suitability] of groups with [region = 1]</metric>
    <metric>mean [suitability] of groups with [region = 2]</metric>
    <metric>mean [suitability] of groups with [region = 3]</metric>
    <metric>mean [suitability] of groups with [region = 4]</metric>
    <metric>mean [suitability] of groups with [region = 5]</metric>
    <metric>mean [suitability] of groups with [region = 6]</metric>
    <metric>death_slope</metric>
    <metric>death_yintercept</metric>
    <metric>timer</metric>
    <enumeratedValueSet variable="number">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birthrate">
      <value value="0.176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weight-move?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fradius">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ticks">
      <value value="3001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trait_list_size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hs_death?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hs_benefit">
      <value value="0"/>
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idw-weight">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plotpop-on?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ex1_test" repetitions="10" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>reset-timer
setup</setup>
    <go>go</go>
    <final>display-cores
ask groups [set size 4]
export-view (word "stills/ex1" "_wm" weight-move? "_rad" fradius "_" behaviorspace-run-number ".png")
display-occ2
export-view (word "stills/ex1" "_wm" weight-move? "_rad" fradius "_" behaviorspace-run-number "o.png")
export-plot "Regional population sizes" (word "stills/s1" "_wm" weight-move? "_rad" fradius "_" behaviorspace-run-number ".csv")</final>
    <timeLimit steps="30"/>
    <metric>count groups</metric>
    <metric>mean [port_freq] of groups with [region = 1]</metric>
    <metric>mean [spain_freq] of groups with [region = 1]</metric>
    <metric>mean [france_freq] of groups with [region = 1]</metric>
    <metric>mean [valencia_freq] of groups with [region = 1]</metric>
    <metric>mean [jura_freq] of groups with [region = 1]</metric>
    <metric>mean [italy_freq] of groups with [region = 1]</metric>
    <metric>mean [port_freq] of groups with [region = 2]</metric>
    <metric>mean [spain_freq] of groups with [region = 2]</metric>
    <metric>mean [france_freq] of groups with [region = 2]</metric>
    <metric>mean [valencia_freq] of groups with [region = 2]</metric>
    <metric>mean [jura_freq] of groups with [region = 2]</metric>
    <metric>mean [italy_freq] of groups with [region = 2]</metric>
    <metric>mean [port_freq] of groups with [region = 3]</metric>
    <metric>mean [spain_freq] of groups with [region = 3]</metric>
    <metric>mean [france_freq] of groups with [region = 3]</metric>
    <metric>mean [valencia_freq] of groups with [region = 3]</metric>
    <metric>mean [jura_freq] of groups with [region = 3]</metric>
    <metric>mean [italy_freq] of groups with [region = 3]</metric>
    <metric>mean [port_freq] of groups with [region = 4]</metric>
    <metric>mean [spain_freq] of groups with [region = 4]</metric>
    <metric>mean [france_freq] of groups with [region = 4]</metric>
    <metric>mean [valencia_freq] of groups with [region = 4]</metric>
    <metric>mean [jura_freq] of groups with [region = 4]</metric>
    <metric>mean [italy_freq] of groups with [region = 4]</metric>
    <metric>mean [port_freq] of groups with [region = 5]</metric>
    <metric>mean [spain_freq] of groups with [region = 5]</metric>
    <metric>mean [france_freq] of groups with [region = 5]</metric>
    <metric>mean [valencia_freq] of groups with [region = 5]</metric>
    <metric>mean [jura_freq] of groups with [region = 5]</metric>
    <metric>mean [italy_freq] of groups with [region = 5]</metric>
    <metric>mean [port_freq] of groups with [region = 6]</metric>
    <metric>mean [spain_freq] of groups with [region = 6]</metric>
    <metric>mean [france_freq] of groups with [region = 6]</metric>
    <metric>mean [valencia_freq] of groups with [region = 6]</metric>
    <metric>mean [jura_freq] of groups with [region = 6]</metric>
    <metric>mean [italy_freq] of groups with [region = 6]</metric>
    <metric>count groups with [region = 1]</metric>
    <metric>count groups with [region = 2]</metric>
    <metric>count groups with [region = 3]</metric>
    <metric>count groups with [region = 4]</metric>
    <metric>count groups with [region = 5]</metric>
    <metric>count groups with [region = 6]</metric>
    <metric>mean [suitability] of groups</metric>
    <metric>mean [suitability] of groups with [region = 1]</metric>
    <metric>mean [suitability] of groups with [region = 2]</metric>
    <metric>mean [suitability] of groups with [region = 3]</metric>
    <metric>mean [suitability] of groups with [region = 4]</metric>
    <metric>mean [suitability] of groups with [region = 5]</metric>
    <metric>mean [suitability] of groups with [region = 6]</metric>
    <metric>death_slope</metric>
    <metric>death_yintercept</metric>
    <metric>timer</metric>
    <enumeratedValueSet variable="number">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birthrate">
      <value value="0.176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weight-move?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fradius">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ticks">
      <value value="3001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trait_list_size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hs_death?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hs_benefit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idw-weight">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plotpop-on?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
1
@#$#@#$#@
